/*
 * ePeriodique: an EFL Periodic Table Of Elements
 * Copyright (C) 2010-2014 Jerome Pinot <ngc891@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "eperiodique.h"

double mwcalc(const char *formula);

static Evas_Object *entry;

static void
clean_result(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
{
   Evas_Object *label = data;

   elm_object_text_set(label, "     g/mol");
}

static void
compute(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
{
   Evas_Object *label = data;
   const char *formula;
   char label_result[128];
   double result;

   formula = elm_entry_entry_get(entry);
   result = mwcalc(formula);
   snprintf(label_result, sizeof(label_result), "%'g g/mol", result);
   elm_object_text_set(label, label_result);
}

int
create_panel(Evas_Object *window, Evas_Object *table)
{
   Evas_Object *panel, *ptable, *label, *label_result, *button;

   /* Add a panel for molar mass computation */
   panel = elm_panel_add(window);
   elm_object_focus_allow_set(panel, EINA_FALSE);
   elm_panel_orient_set(panel, ELM_PANEL_ORIENT_BOTTOM);
   elm_panel_toggle(panel);
   evas_object_size_hint_weight_set(panel, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(panel, EVAS_HINT_FILL, EVAS_HINT_FILL);
   evas_object_show(panel);
   elm_table_pack(table, panel, 7, 8, 7, 4);

   /* Create a table for the panel */
   ptable = elm_table_add(window);
   elm_table_homogeneous_set(ptable, EINA_FALSE);
   evas_object_size_hint_weight_set(ptable, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
   evas_object_size_hint_align_set(ptable, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_object_content_set(panel, ptable);
   evas_object_show(ptable);

   /* Label for panel */
   label = elm_label_add(window);
   elm_object_text_set(label, _("Molecular formula:"));
   evas_object_size_hint_weight_set(label, 0.8, 0.8);
   elm_table_pack(ptable, label, 0, 0, 1, 1);
   evas_object_show(label);

   /* Entry for panel */
   entry = elm_entry_add(window);
   elm_entry_cnp_mode_set(entry, ELM_CNP_MODE_PLAINTEXT);
   elm_entry_single_line_set(entry, EINA_TRUE);
   elm_entry_scrollable_set(entry, EINA_TRUE);
   evas_object_size_hint_weight_set(entry, 0.8, 0.8);
   evas_object_size_hint_align_set(entry, EVAS_HINT_FILL, EVAS_HINT_FILL);
   elm_table_pack(ptable, entry, 1, 0, 1, 1);
   evas_object_show(entry);

   /* Label for panel */
   label = elm_label_add(window);
   elm_object_text_set(label, _("Molar mass:"));
   evas_object_size_hint_weight_set(label, 0.8, 0.8);
   elm_table_pack(ptable, label, 0, 1, 1, 1);
   evas_object_show(label);

   /* Label for result */
   label_result = elm_label_add(window);
   elm_object_text_set(label_result, "     g/mol");
   evas_object_size_hint_weight_set(label_result, 0.8, 0.8);
   elm_table_pack(ptable, label_result, 1, 1, 1, 1);
   evas_object_show(label_result);

   /* Button for panel */
   button = elm_button_add(window);
   elm_object_text_set(button, _("Compute"));
   evas_object_size_hint_weight_set(button, 0.8, 0.8);
   elm_table_pack(ptable, button, 0, 2, 2, 1);
   evas_object_show(button);

   /* Add callbacks */
   evas_object_smart_callback_add(entry, "changed,user", clean_result, (void *)label_result);
   evas_object_smart_callback_add(entry, "activated", compute, (void *)label_result);
   evas_object_smart_callback_add(button, "clicked", compute, (void *)label_result);

   return EXIT_SUCCESS;
}

/* vim: set ts=8 sw=3 sts=3 expandtab cino=>5n-3f0^-2{2(0W1st0 : */
